@@ -9,6 +9,7 @@ import seaborn as sns
 from matplotlib.patches import Patch
 from sklearn.manifold import TSNE
 from wordcloud import WordCloud
+from sklearn.cluster import KMeans
 
 from chester.zero_break.problem_specification import DataInfo
 
@@ -159,7 +160,7 @@ class CategoricalPreModelAnalysis:
             else:
                 max_plots = min(9, top_features)
                 dim = min(math.ceil(math.sqrt(max_plots)), 2)
-                fig, ax = plt.subplots(dim, dim, figsize=(18, 15))
+                fig, ax = plt.subplots(dim, dim, figsize=(14, 4 + 4 * dim))
                 fig.tight_layout()
                 if classification_row_percent:
                     plt.suptitle("Partial Plot to Identify Patterns between Sampled Categorical Features and Target\n"
@@ -170,6 +171,8 @@ class CategoricalPreModelAnalysis:
                                  "Showing % from Target (column)",
                                  fontsize=14, fontweight='bold')
                 for i, col in enumerate(top_feature_names):
+                    if i >= dim * dim:
+                        break
                     ax_i = ax[i // dim, i % dim]
                     if classification_row_percent:
                         crosstab = pd.crosstab(self.data[col], self.target, normalize='index') * 100
@@ -191,12 +194,8 @@ class CategoricalPreModelAnalysis:
         if self.data_info.problem_type_val in ["Regression"]:
             max_plots = 9
             top_n = self.data[:top_features].columns
-            dim = math.ceil(math.sqrt(len(top_n)))
-            num_rows = math.ceil(max_plots / dim)
-            fig, ax = plt.subplots(num_rows, dim, figsize=(20, 20))
-            fig.tight_layout()
-
-            from sklearn.cluster import KMeans
+            dim = max(math.floor(math.sqrt(min(max_plots, len(top_n)))), 2)
+            fig, ax = plt.subplots(dim, dim, figsize=(20, 4 + 4 * dim))
             target = self.target
             plt.suptitle(
                 "Partial Plot to Identify Patterns between Categorical Sampled Features and Target (grouped by kmeans)",
@@ -204,42 +203,40 @@ class CategoricalPreModelAnalysis:
                 fontweight='bold')
             grid_size = math.ceil(math.sqrt(top_features))
             num_features = min(grid_size * grid_size, top_features)
-            num_rows = int(np.ceil(num_features / grid_size))
             for i, col in enumerate(top_feature_names[:num_features]):
-                plt.subplot(num_rows, grid_size, i + 1)
-                column = self.data[col]
-                if column.dtype == "object":
-                    column = column.astype("category").cat.codes
-                    column = column[column < 5]
-                    top_values = list(self.data[col].astype("category").cat.categories[:5])
-                    data_filtered = self.data[self.data[col].isin(top_values)]
-                    sns.boxplot(x=column, y=target, data=data_filtered)
+                if i >= dim * dim:
+                    break
+                plt.subplot(dim, dim, i + 1)
+                column = self.data[col].apply(lambda x: "'" + str(x))
+                new_df = pd.concat([column, target], axis=1)
+                top_values = list(column.value_counts().nlargest(5).index)
+                data_filtered = new_df[column.isin(top_values)]
+                sns.boxplot(x=col, y=target, data=data_filtered)
                 plt.ylabel("Target")
                 plt.xlabel("{} Value".format(col))
                 plt.subplots_adjust(hspace=0.5, wspace=0.5)
-                plt.show()
-                plt.close()
+            plt.show()
+            plt.close()
         elif self.data_info.problem_type_val in ["Multiclass classification"]:
             max_plots = 16
-            top_n = self.data[:top_features].columns
-            dim = math.ceil(math.sqrt(len(top_n)))
-            num_rows = math.ceil(max_plots / dim)
-            fig, ax = plt.subplots(num_rows, dim, figsize=(20, 20))
+            top_n = self.data[:max_plots].columns
+            dim = max(math.floor(math.sqrt(len(top_n))), 2)
+            fig, ax = plt.subplots(dim, dim, figsize=(19, 4 * dim))
             fig.tight_layout()
             plt.suptitle(
                 "Heatmap to Show Correlation between Sampled Categorical Features (top 5 categories) and Target",
-                fontsize=16,
+                fontsize=15,
                 fontweight='bold')
             for i, col in enumerate(top_feature_names):
                 if i > 15:
                     return None
-                plt.subplot(num_rows, dim, i + 1)
+                plt.subplot(dim, dim, i + 1)
                 crosstab = pd.crosstab(self.data[col], self.target, normalize='index') * 100
                 crosstab = crosstab[(crosstab.T != 0).any()]
                 crosstab = crosstab.loc[:, (crosstab != 0).any(axis=0)]
                 crosstab = crosstab.loc[crosstab.sum(axis=1).sort_values(ascending=False).index[:5]]
                 sns.heatmap(crosstab, annot=False, cmap="YlGnBu", fmt='g')
-                plt.title(col, fontsize=12, fontweight='bold')
+                plt.title(col, fontsize=10, fontweight='bold')
             plt.show()
             plt.close()
 
