@@ -206,7 +206,7 @@ def run_madcat(
             title = "\nNumerical Feature statistics:"
             print(title)
             rc.save_text(title)
-            NumericStats(data_info_num_stats, max_print=max_stats_col_width).run(plot=plot_stats)
+            # NumericStats(data_info_num_stats, max_print=max_stats_col_width).run(plot=plot_stats)
         title = "\nCategorical Feature statistics:"
         print(title)
         rc.save_text(title)
@@ -234,6 +234,7 @@ def run_madcat(
         rc.save_text("** model pre analysis report:")
         print(chapter_title('model pre analysis'))
         # label stats
+        print("Label pre model analysis:")
         TargetPreModelAnalysis(data_info=data_info, time_series_handler=time_series_handler).run(plot)
         TimeSeriesPreModelAnalysis(data_info=data_info, time_series_handler=time_series_handler).run()
         # num, cat pre model
@@ -244,8 +245,8 @@ def run_madcat(
         plt.close()
         # cat if found any
         cat_not_ts = data_info.feature_types_val["categorical"]
-        # cat_not_ts = [col for col in cat_not_ts if not col.startswith('ts_')]
         if len(cat_not_ts) > 0:
+            print("Categorical pre model analysis:")
             CategoricalPreModelAnalysis(data_info).run(plot)
     ####################################################
     # model
