@@ -1,15 +1,43 @@
+import itertools
+import re
+from datetime import datetime
+
 import pandas as pd
+# need an extension for ts module
 from dateutil.parser import parse
 
 from chester.zero_break.text_detector import determine_if_text_or_categorical_column
 
 
-# need an extension for ts module
 def is_date(string):
+    if len(string) < 7:
+        return False
+    # Define regular expressions to match various date and datetime formats
+    date_formats = ["%Y-%m-%d", "%m/%d/%Y", "%d/%m/%Y"]
+    datetime_formats = ["%Y-%m-%d %H:%M:%S", "%Y-%m-%d %H:%M", "%m/%d/%Y %H:%M:%S", "%m/%d/%Y %H:%M"]
+    regexes = [
+        re.compile(r'\d{4}-\d{2}-\d{2}'),
+        re.compile(r'\d{2}/\d{2}/\d{4}'),
+        re.compile(r'\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}'),
+        re.compile(r'\d{4}-\d{2}-\d{2} \d{2}:\d{2}'),
+        re.compile(r'\d{2}/\d{2}/\d{4} \d{2}:\d{2}:\d{2}'),
+        re.compile(r'\d{2}/\d{2}/\d{4} \d{2}:\d{2}')
+    ]
+
+    # Check if the string matches any of the known formats or regexes
     try:
         parse(string)
         return True
-    except:
+    except ValueError:
+        for fmt in date_formats + datetime_formats:
+            try:
+                datetime.strptime(string, fmt)
+                return True
+            except ValueError:
+                pass
+        for regex in regexes:
+            if regex.match(string):
+                return True
         return False
 
 
@@ -25,6 +53,10 @@ class DataInfo:
         self.model_selection_val = None
         self.label_transformation_val = None
         self.rows = self.data.shape[0]
+        self.feature_types_val_flatten = None
+
+    def get_all_features(self):
+        return list(set(itertools.chain(*self.feature_types_val.values())))
 
     def calculate(self):
         self.problem_type_val = self.problem_type()
@@ -142,11 +174,11 @@ class DataInfo:
         if problem_type == "No target variable":
             return None
         elif problem_type == "Binary regression":
-            return ["MSE", "MAE", "MAPE", "ROC"]
+            return ["MSE", "ROC", "MAE", "MAPE"]
         elif problem_type == "Binary classification":
             return ["Accuracy", "Precision", "Recall", "F1"]
         elif problem_type == "Regression":
-            return ["MSE", "MAE", "MAPE"]
+            return ["R2", "MSE", "MAE", "MAPE"]
         elif problem_type == "Multiclass classification":
             return ["Accuracy", "Precision", "Recall", "F1"]
 
@@ -181,6 +213,6 @@ class DataInfo:
         if self.target:
             report += "Loss Function: " + self.loss_detector_val + "\n"
         report += "Evaluation Metrics: " + str(self.metrics_detector_val) + "\n"
-        report += "Model Selection: " + str(self.model_selection_val) + "\n"
+        report += "Optional Models: " + str(self.model_selection_val) + "\n"
         # report += "Label Transformation: " + str(self.label_transformation_val)
         return report
